@@ -4,7 +4,5 @@ So far the user can get stats from the duels lobby.
 
 Go to the README.md for usage.
 """
-from .bedwarsstats import *
-from .duelstats import *
 from .errors import *
 from .minecraftstats import *
\ No newline at end of file
